==> hs-glib-0.12.4_2.txz: usr/local/lib/cabal/ghc-7.6.3/glib-0.12.4/register.sh <==
#!/bin/sh
echo 'name: glib
version: 0.12.4
id: glib-0.12.4-e3c24025d434894ff47dcfccf269abe4

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the GLIB library for Gtk2Hs.
description: The GNU Library is a collection of C data structures and utility
             function for dealing with Unicode. This package only binds as
             much functionality as required to support the packages that
             wrap libraries that are themselves based on GLib.
category: System
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules: System.Glib System.Glib.GError
                 System.Glib.Properties System.Glib.Attributes System.Glib.Signals
                 System.Glib.MainLoop System.Glib.GDateTime System.Glib.GObject
                 System.Glib.Utils System.Glib.StoreValue System.Glib.FFI
                 System.Glib.Flags System.Glib.UTFString System.Glib.Types
                 System.Glib.GList System.Glib.GString System.Glib.GType
                 System.Glib.GTypeConstants System.Glib.GValue
                 System.Glib.GValueTypes System.Glib.GParameter
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.6.3/glib-0.12.4
library-dirs: /usr/local/lib/cabal/ghc-7.6.3/glib-0.12.4
              /usr/local/lib
hs-libraries: HSglib-0.12.4
extra-libraries: gobject-2.0 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/glib-2.0
includes:
depends: base-4.6.0.1-f7bdc8987bd5928e0ee6e8cc8b246a88
         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.6.3/glib-0.12.4/html/glib.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.6.3/glib-0.12.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> hs-glib-0.12.5.4.txz: usr/local/lib/cabal/ghc-7.8.3/glib-0.12.5.4/register.sh <==
#!/bin/sh
export PATH='/usr/local/libexec/ccache:/sbin:/bin:/usr/sbin:/usr/bin:/usr/games:/usr/local/sbin:/usr/local/bin:/root/bin'
echo 'name: glib
version: 0.12.5.4
id: glib-0.12.5.4-8d38fc790091beced6c3824ddababb7f

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the GLIB library for Gtk2Hs.
description: The GNU Library is a collection of C data structures and utility
             function for dealing with Unicode. This package only binds as
             much functionality as required to support the packages that
             wrap libraries that are themselves based on GLib.
category: System
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules: System.Glib System.Glib.GError
                 System.Glib.Properties System.Glib.Attributes System.Glib.Signals
                 System.Glib.MainLoop System.Glib.GDateTime System.Glib.GObject
                 System.Glib.Utils System.Glib.StoreValue System.Glib.FFI
                 System.Glib.Flags System.Glib.UTFString System.Glib.Types
                 System.Glib.GList System.Glib.GString System.Glib.GType
                 System.Glib.GTypeConstants System.Glib.GValue
                 System.Glib.GValueTypes System.Glib.GParameter
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.8.3/glib-0.12.5.4
library-dirs: /usr/local/lib/cabal/ghc-7.8.3/glib-0.12.5.4
              /usr/local/lib
hs-libraries: HSglib-0.12.5.4
extra-libraries: gobject-2.0 glib-2.0 intl
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/glib-2.0
includes:
depends: base-4.7.0.1-812360bc88c9859b8259f0d90b6e2faa
         containers-0.5.5.1-23e2a2b94d6e452c773209f31d8672c5
         utf8-string-0.3.8-1953503a54d3f55fc6ab02431dfeac7c
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.8.3/glib-0.12.5.4/html/glib.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.8.3/glib-0.12.5.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
